'use client';
import { signInWithMicrosoft } from '@/lib/queries';
import {
  StatusMessage,
  SubmitButton,
  type SubmitButtonProps,
} from '@/components/default/forms';
import { useAuth } from '@/lib/hooks/context';
import { useRouter } from 'next/navigation';
import { useState } from 'react';
import { useSupabaseClient } from '@/utils/supabase';
import { FaMicrosoft } from 'react-icons/fa';
import { type ComponentProps } from 'react';
import { cn } from '@/lib/utils';

export type SignInWithMicrosoftProps = {
  submitButtonProps?: SubmitButtonProps;
  formClassName?: ComponentProps<'form'>['className'];
  formProps?: Omit<ComponentProps<'form'>, 'className'>;
  textClassName?: ComponentProps<'p'>['className'];
  textProps?: Omit<ComponentProps<'p'>, 'className'>;
  iconClassName?: ComponentProps<'svg'>['className'];
  iconProps?: Omit<ComponentProps<'svg'>, 'className'>;
};

export const SignInWithMicrosoft = ({
  submitButtonProps,
  formClassName,
  formProps,
  textClassName,
  textProps,
  iconClassName,
  iconProps,
} : SignInWithMicrosoftProps) => {
  const router = useRouter();
  const { loading, refreshUser } = useAuth();
  const [statusMessage, setStatusMessage] = useState('');
  const [ isLoading, setIsLoading ] = useState(false);
  const supabase = useSupabaseClient();

  const handleSignInWithMicrosoft = async (e: React.FormEvent) => {
    e.preventDefault();
    try {
      if (!supabase) throw new Error('Supabase client not found');
      setStatusMessage('');
      setIsLoading(true);
      const result = await signInWithMicrosoft(supabase);
      if (result.data.url) window.location.href = result.data.url;
      else setStatusMessage(`There was a problem signing in with Microsoft!`);
    } catch (error) {
      setStatusMessage(`Error signing in: ${error as string}`);
    } finally {
      setIsLoading(false);
      await refreshUser();
      router.push('');
    }
  };

  return (
    <form
      onSubmit={handleSignInWithMicrosoft}
      className={cn('my-4', formClassName)}
      {...formProps}
    >
      <SubmitButton
        disabled={isLoading || loading}
        pendingText='Signing in...'
        className={cn('w-full', submitButtonProps?.className)}
        {...submitButtonProps}
      >
        <div className='flex items-center gap-2'>
          <FaMicrosoft className={cn('size-5', iconClassName)} {...iconProps} />
          <p className={cn('text-[1.0rem]', textClassName)} {...textProps}>
            Sign In with Microsoft
          </p>
        </div>
  </SubmitButton>
      {statusMessage && <StatusMessage message={{ error: statusMessage }} />}
    </form>
  );
};
