import { type ComponentProps } from 'react';
import { cn } from '@/lib/utils';

type Message =
| { success: string}
| { error: string}
| { message: string}

type StatusMessageProps = {
  message: Message;
  containerClassName?: ComponentProps<'div'>['className'];
  containerProps?: Omit<ComponentProps<'div'>, 'className'>;
  textClassName?: ComponentProps<'div'>['className'];
  textProps?: Omit<ComponentProps<'div'>, 'className'>;
};

export const StatusMessage = ({
  message,
  containerClassName,
  containerProps,
  textClassName,
  textProps,
}: StatusMessageProps) => {
  return (
    <div
      className={cn(
        'flex flex-col gap-2 w-full\
          text-sm bg-accent rounded-md p-2 px-4',
        containerClassName,
      )}
      {...containerProps}
    >
      {'success' in message && (
        <div className={cn(
          'dark:text-green-500 text-green-700',
          textClassName
        )}
          {...textProps}
        >
          {message.success}
        </div>
      )}
      {'error' in message && (
        <div className={cn('text-destructive', textClassName)}>
          {message.error}
        </div>
      )}
      {'message' in message && (
        <div className={textClassName}>
          {message.message}
        </div>
      )}
    </div>
  );
};
