'use client';
import { Button } from '@/components/ui';
import { type ComponentProps } from 'react';
import { useFormStatus } from 'react-dom';
import { Loader2 } from 'lucide-react';
import { cn } from '@/lib/utils';

export type SubmitButtonProps = Omit<
  ComponentProps<typeof Button>,
  'type' | 'aria-disabled' | 'className',
> & {
  className?: ComponentProps<typeof Button>['className'];
  pendingText?: string;
  pendingTextClassName?: ComponentProps<'p'>['className'];
  pendingTextProps?: Omit<ComponentProps<'p'>, 'className'>;
  loaderClassName?: ComponentProps<typeof Loader2>['className'];
  loaderProps?: Omit<ComponentProps<typeof Loader2>, 'className'>;
};

export const SubmitButton = ({
  children,
  className,
  pendingText = 'Submitting...',
  pendingTextClassName,
  pendingTextProps,
  loaderClassName,
  loaderProps,
  ...props
}: SubmitButtonProps) => {
  const { pending } = useFormStatus();
  return (
    <Button
      className={cn('cursor-pointer', className)}
      type='submit'
      aria-disabled={pending}
      {...props}
    >
      {pending || props.disabled ? (
        <>
          <Loader2
            className={cn('mr-2 h-4 w-4 animate-spin', loaderClassName)}
            {...loaderProps}
          />
          <p
            className={cn('text-sm font-medium', pendingTextClassName)}
            {...pendingTextProps}
          >
            {pendingText}
          </p>
        </>
      ) : (
          children
      )}
    </Button>
  );
};
