'use client';
import Image from 'next/image';
import React, { createContext, useContext, useState } from 'react';
import type { ReactNode } from 'react';
import { Button } from '@/components/ui';
import { type ComponentProps } from 'react';
import { cn } from '@/lib/utils';

type TVModeContextProps = {
  tvMode: boolean;
  toggleTVMode: () => void;
};

type TVToggleProps = {
  buttonClassName?: ComponentProps<typeof Button>['className'];
  buttonProps?: Omit<ComponentProps<typeof Button>, 'className'>;
  size: number;
};

const TVModeContext = createContext<TVModeContextProps | undefined>(undefined);

const TVModeProvider = ({ children }: { children: ReactNode }) => {
  const [tvMode, setTVMode] = useState(false);
  const toggleTVMode = () => {
    setTVMode((prev) => !prev);
  };
  return (
    <TVModeContext.Provider value={{ tvMode, toggleTVMode }}>
      {children}
    </TVModeContext.Provider>
  );
};

const useTVMode = () => {
  const context = useContext(TVModeContext);
  if (!context) {
    throw new Error('useTVMode must be used within a TVModeProvider');
  }
  return context;
};

const TVToggle = ({
  buttonClassName,
  buttonProps = {
    variant: 'outline',
    size: 'default',
  },
  size = 25,
}: TVToggleProps) => {
  const { tvMode, toggleTVMode } = useTVMode();
  return (
    <Button
      onClick={toggleTVMode}
      className={cn('my-auto cursor-pointer', buttonClassName)}
      {...buttonProps}
    >
      {tvMode ? (
        <Image
          src='/icons/tv/exit.svg'
          alt='Exit TV Mode'
          width={size}
          height={size}
        />
      ) : (
        <Image
          src='/icons/tv/enter.svg'
          alt='Enter TV Mode'
          width={size}
          height={size}
        />
      )}
    </Button>
  );
};

export { TVModeProvider, useTVMode, TVToggle };
